pytest-whirlwind
################

.. image:: https://travis-ci.org/supakeen/pytest-whirlwind.svg?branch=master
    :target: https://travis-ci.org/supakeen/pytest-whirlwind

.. image:: https://readthedocs.org/projects/pytest-whirlwind/badge/?version=latest
    :target: https://pytest-whirlwind.readthedocs.io/en/latest/

.. image:: https://pytest-whirlwind.readthedocs.io/en/latest/_static/license.svg
    :target: https://github.com/supakeen/pytest-whirlwind/blob/master/LICENSE

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black

.. image:: https://img.shields.io/pypi/v/pytest-whirlwind
    :target: https://pypi.org/project/pytest-whirlwind

.. image:: https://codecov.io/gh/supakeen/pytest-whirlwind/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/supakeen/pytest-whirlwind
